==> 0.2.0.tar.gz: lib/src/custom/toggle_open.dart <==
part of tags;

final Tag toggleOpen = createTag((BindModel onBind) => 
    bindModel(new ToggleOpen(), onBind));

/// A control that allows toggling between an [isOpen] and an [isClosed] state.
class ToggleOpen implements HasElement {    
  Element _element;
  Element get element => _element;    
  
  ContentElement _content; 
  ContentElement _toggle;
  
  StreamSubscription<MouseEvent> _documentClickListener;
  
  bool _isOpen = false;
  /// Whether or not this control is open.
  bool get isOpen => _isOpen;
       set isOpen(bool value) {
         if (value != _isOpen) {           
           _isOpen = value;
           if (_isOpen) {
             _content.select = '.open';
             _documentClickListener = 
                 document.onClick.listen((MouseEvent ev) => isOpen = false);
           }
           else {
             _documentClickListener.cancel();
             _content.select = '.toggle';
           }
           if (_states.hasListener && !_states.isPaused) _states.add(_isOpen);
         }
       }

  /// Whether or not this control is closed.
  bool get isClosed => !_isOpen;
       
  final _states = new StreamController<bool>();
  /// An observable stream of this control's state transitions.
  /// A _true_ value represents [isOpen] and a _false_ represents [isClosed].
  Stream<bool> get states => _states.stream;
  
  /// Constructs a new toggle-open control.
  ToggleOpen() {
    _element = div(() {
      shadow(() {
        _toggle = content()..select='.toggle';
        // Selecting '.toggle' here is a way to ensure it selects nothing, as
        // the distribution will always go to the first match for '.toggle'.
        _content = content()..select='.toggle';       
      });
    })..onClick.listen((MouseEvent ev) {
        isOpen = !_isOpen;
        ev.stopPropagation();
      })
      ..onKeyUp.listen((KeyboardEvent ev) {
        if (ev.keyCode == KeyCode.ESC) isOpen = false;
      });
  }
}

==> 0.2.1.tar.gz: lib/src/custom/toggle_open.dart <==
part of tags;

final Tag toggleOpen = createTag((BindModel onBind) => 
    bindModel(new ToggleOpen(), onBind));

/// A control that allows toggling between an [isOpen] and an [isClosed] state.
class ToggleOpen implements HasElement {
  
  Element _element;
  Element get element => _element;    
  
  ContentElement _content; 
  ContentElement _toggle;
  
  StreamSubscription<MouseEvent> _documentClickListener;
  
  bool _isOpen = false;
  /// Whether or not this control is open.
  bool get isOpen => _isOpen;
       set isOpen(bool value) {
         if (value != _isOpen) {           
           _isOpen = value;
           if (_isOpen) {
             _content.select = '.open';
             _documentClickListener = 
                 document.onClick.listen((MouseEvent ev) => isOpen = false);
           } else {
             _documentClickListener.cancel();
             _content.select = '.toggle';
           }
           if (_states.hasListener && !_states.isPaused) _states.add(_isOpen);
         }
       }

  /// Whether or not this control is closed.
  bool get isClosed => !_isOpen;
       
  final _states = new StreamController<bool>();
  /// An observable stream of this control's state transitions.
  /// A _true_ value represents [isOpen] and a _false_ represents [isClosed].
  Stream<bool> get states => _states.stream;
  
  /// Creates a new toggle-open control.
  ToggleOpen() {
    _element = div(() {
      shadow(() {
        _toggle = content()..select='.toggle';
        // Selecting '.toggle' here is a way to ensure it selects nothing, as
        // the distribution will always go to the first match for '.toggle'.
        _content = content()..select='.toggle';       
      });
    })
    ..onClick.listen((MouseEvent ev) {
      isOpen = !_isOpen;
      ev.stopPropagation();
    })
    ..onKeyUp.listen((KeyboardEvent ev) {
      if (ev.keyCode == KeyCode.ESC) isOpen = false;
    });
  }
}
